@@ -124,10 +124,12 @@ static gboolean verify_cursor_theme(GKeyFile *kf, const char *cursor_theme,
     ret = g_key_file_load_from_file(kf, fpath, 0, NULL);
     g_free(fpath);
 
-    fpath = g_build_filename("icons", cursor_theme, "index.theme", NULL);
     if (!ret)
+    {
+        fpath = g_build_filename("icons", cursor_theme, "index.theme", NULL);
         ret = g_key_file_load_from_data_dirs(kf, fpath, NULL, 0, NULL);
-    g_free(fpath);
+        g_free(fpath);
+    }
 
     if (ret)
     {
@@ -240,8 +242,25 @@ static void lxappearance_save_gtkrc()
         "GTK_ICON_SIZE_DIALOG"
     };
 
-    char* file_path = g_build_filename(g_get_home_dir(), ".gtkrc-2.0", NULL);
+    char **gtkrc_files = gtk_rc_get_default_files();
+    char *file_path = NULL;
     GString* content = g_string_sized_new(512);
+
+    /* check for availability of path via GTK2_RC_FILES */
+    while (gtkrc_files && gtkrc_files[0])
+    {
+        g_debug("checking gtkrc path %s",gtkrc_files[0]);
+        if (g_str_has_prefix(gtkrc_files[0], g_get_home_dir()))
+            break;
+        else
+            gtkrc_files++;
+    }
+    /* if none found then use hardcoded one */
+    if (gtkrc_files == NULL || gtkrc_files[0] == NULL)
+    {
+        g_debug("none found, use hardcoded %s/.gtkrc-2.0",g_get_home_dir());
+        file_path = g_build_filename(g_get_home_dir(), ".gtkrc-2.0", NULL);
+    }
     g_string_append(content,
         "# DO NOT EDIT! This file will be overwritten by LXAppearance.\n"
         "# Any customization should be done in ~/.gtkrc-2.0.mine instead.\n\n");
@@ -317,7 +336,10 @@ static void lxappearance_save_gtkrc()
     }
 #endif
 
-    g_file_set_contents(file_path, content->str, content->len, NULL);
+    if (file_path)
+        g_file_set_contents(file_path, content->str, content->len, NULL);
+    else
+        g_file_set_contents(gtkrc_files[0], content->str, content->len, NULL);
 
     /* Save also in GTK3 folder
        Content shold be different from the gtk2 one
